@@ -7,7 +7,6 @@ import yaml
 from cli import *
 import pprint
 from pathlib import Path
-from gtts import gTTS
 from jinja2 import Environment, FileSystemLoader
 
 class NxPyDocs():
@@ -47,7 +46,7 @@ class NxPyDocs():
         if self.command == "all":
             for single_command in self.supported_templates:
                 self.command = single_command
-                command_output = clid(f"{ self.command }")
+                command_output = clid( '%s' % self.command )
                 parsed_json = json.dumps(command_output, indent=4, sort_keys=True)
                 pp.pprint(parsed_json)
                 if "Cannot" in parsed_json:
@@ -57,7 +56,7 @@ class NxPyDocs():
                         self.pick_filetype(parsed_json)
         else:
             if self.command in self.supported_templates:
-                command_output = clid(f"{ self.command }")
+                command_output = clid( '%s' % self.command )
                 parsed_json = json.dumps(command_output, indent=4, sort_keys=True)
                 pp.pprint(parsed_json)
                 if "Cannot" in parsed_json:
@@ -81,28 +80,21 @@ class NxPyDocs():
             self.markdown_file(parsed_json)
         elif self.filetype == 'csv':
             self.csv_file(parsed_json)
-        elif self.filetype == 'svg':
-            self.svg_file(parsed_json)
-        elif self.filetype == 'png':
-            self.png_file(parsed_json)            
-        elif self.filetype == 'mindmap':
-            self.mindmap_file(parsed_json)
-        elif self.filetype == 'mp3':
-            self.mp3_file(parsed_json)            
+            self.mindmap_file(parsed_json)           
         elif self.filetype == 'all':
             self.all_files(parsed_json)
 
     def json_file(self, parsed_json):
         with open(f'{self.command}.json', 'w') as f:
             f.write(parsed_json)
-        click.secho(f"JSON file created at { sys.path[0] }/{self.command}.json",
+        click.secho("JSON file created at %s / %s.json" % (sys.path[0],self.command),
         fg='green')
 
     def yaml_file(self, parsed_json):
         clean_yaml = yaml.dump(json.loads(parsed_json), default_flow_style=False)
         with open(f'{self.command}.yaml', 'w') as f:
             f.write(clean_yaml)
-        click.secho(f"YAML file created at { sys.path[0] }/{self.command}.yaml",
+        click.secho("YAML file created at %s / %s.yaml" % (sys.path[0],self.command),
         fg='green')
 
     def html_file(self, parsed_json):
@@ -113,7 +105,7 @@ class NxPyDocs():
             data_to_template=json.loads(parsed_json))
         with open(f'{self.command}.html', 'w') as f:
             f.write(html_output)
-        click.secho(f"HTML file created at { sys.path[0] }/{self.command}.html",
+        click.secho("HTML file created at %s / %s.html" % (sys.path[0],self.command),
             fg='green')
 
     def markdown_file(self, parsed_json):
@@ -124,7 +116,7 @@ class NxPyDocs():
             data_to_template=json.loads(parsed_json))
         with open(f'{self.command}.md', 'w') as f:
             f.write(markdown_output)
-        click.secho(f"Markdown file created at { sys.path[0] }/{self.command}.md",
+        click.secho("Markdown file created at %s / %s.md" % (sys.path[0],self.command),
             fg='green')
 
     def csv_file(self, parsed_json):
@@ -136,15 +128,7 @@ class NxPyDocs():
             hostname=self.hostname)
         with open(f'{self.command}.csv', 'w') as f:
             f.write(csv_output)
-        click.secho(f"CSV file created at { sys.path[0] }/{self.command}.csv",
-            fg='green')
-
-    def svg_file(self, parsed_json):
-        console = Console(record=True)
-        console.print(parsed_json)
-        console.save_svg(f"{self.command}.svg",
-            title=f"{self.command}")
-        click.secho(f"SVG file created at { sys.path[0] }/{self.command}.svg",
+        click.secho("CSV file created at %s / %s.csv" % (sys.path[0],self.command),
             fg='green')
 
     def mindmap_file(self, parsed_json):
@@ -157,22 +141,7 @@ class NxPyDocs():
         with open(f'{self.command} mindmap.md', 'w') as f:
             f.write(mindmap_output)
         click.secho(
-            f"Mindmap file created at { sys.path[0] }/{self.command}.md",
-            fg='green')
-
-    def mp3_file(self, parsed_json):
-        template_dir = Path(__file__).resolve().parent
-        env = Environment(loader=FileSystemLoader(str(template_dir)))
-        mp3_template = env.get_template(f'{self.os} mp3.j2')
-        mp3_output = mp3_template.render(hostname = self.hostname,
-            command = self.command,
-            data_to_template=json.loads(parsed_json))
-        language = 'en-US'
-        mp3 = gTTS(text = mp3_output, lang=language)
-        # Save MP3
-        mp3.save(f'{self.command}.mp3')
-        click.secho(
-            f"MP3 file created at { sys.path[0] }/{self.command}.md",
+            "Mindmap file created at %s / %s.md" % (sys.path[0],self.command),
             fg='green')
 
     def all_files(self, parsed_json):
@@ -182,9 +151,6 @@ class NxPyDocs():
         self.markdown_file(parsed_json)
         self.csv_file(parsed_json)
         self.mindmap_file(parsed_json)
-        self.svg_file(parsed_json)
-        self.png_file(parsed_json)
-        self.mp3_file(parsed_json)
 
 @click.command()
 @click.option('--command',
@@ -199,10 +165,7 @@ class NxPyDocs():
                         'html',
                         'csv',
                         'markdown',
-                        'svg',
-                        'png',
                         'mindmap',
-                        'mp3',
                         'all'],
         case_sensitive=True),
     help='Filetype to output captured network state to',
